%*******************************************************************%
%-------------------------propDesign--------------------------------%
%*******************************************************************%
% This MATLAB code was developed as part of the master thesis in
% marine hydrodynamics at NTNU titled"The Influence of the Choice
% of Propeller Design Tool on Propeller Performance"
%   by  Edvard Knutsen Skaaland             spring 2016
%
% This is propeller design code based on lifting line theory with
% Goldstein factors to calculate induced velocities. Foil section 
% camber and thickness values are based on NACA a = 0.8 and NACA 66
% tables. The circulation distribution is set to reach zero at the hub
% center to have a more realistic non-zero circulation value at the 
% root. 
%
% NOTE TO USER:
% The design approach used in this program is based on the method described
% in the lecture notes by Sverre Steen for the course Naval Hydrodynamics
% at NTNU. This code was only ever intended to generate some basic
% geometries which could be further developed by other design programs.  
% If someone is reading this with the intention of using this code, I refer
% to the recommendation section of my thesis for ways to improve it.


% INPUT DATA
D = 3.5; % propeller diameter [m]
Z = 4; % number of blades
dHub = 1.020; % hub diameter [m]
rHub = dHub/2; % hub radius [m]
RPM = 150; % revolutions per minute
Vs = 15.5; % ship speed [knots]
h = 4.5; % shaft immersion [m]
NoS = 100; % number of strips
Lship = 67; % Lpp [m]
Lmodel = 67/14.8; % Length of model ship

% Radial wake field had to be assigned in either radialWake_model.m if
% model measurements are given, or in radialWake.m for full scale wake.

RShip = 285040; % Ship resistance in newton
tShip = 0.289;  % thrust deduction
Thrust = RShip/(1-tShip); % Required thrust
cavSafe = 0.8; % Cavitation safety factor
% OPTIMIZATION PARAMETERS
a = linspace(0.0,0.5,6);
m = [0.2:0.1:1.0];
c_0 = 0.4*D/2; % Chord length at root
c_1 = 0.9; % Max chord length

% opt = optimizeChordAndCirc(c_1,a,m,prop,Thrust);
% print = 0; % Print values if print = 1
% opt = opt.optimize(c_0,print);
prop = Propeller(D,Z,rHub,RPM,Vs*0.5144444444,h,NoS,Lship,Lmodel);
   
% After optimization procedure is done, change parameters to the ones
% reccomended in 
a = 0.5;
m = 0.5;
prop.c = chordLength(prop.x, c_0, c_1, a, m);

k = 5.8197;
a = 0.5;
m = 0.6;

prop.Gamma = gammaCalc(prop.r./prop.R,k,a,m);
prop = prop.calculateVelocities();
prop = prop.calculateForces();
prop = prop.cavitationCheck(cavSafe);
prop = prop.calculateGeometricVariables();
