classdef kThrust
   % This class is set up to find the k value needed in order
   % for the propeller to provide sufficient thrust
   properties
       a;   % circulation form functio parameter
       m;   % circulation form function parameter
       prop1;   % propeller object
       OPTIONS; % fzero solver options
   end
   methods
       function obj = kThrust(prop,a,m)
          % Set error tolerance for the root solver fzero
          obj.OPTIONS = optimset('TolFun',6e-6);
          
          obj.a = a; % circulation form function parameter
          obj.m = m; % circulation form function parameter
          obj.prop1 = prop; % propeller object
       end
       function thrust = thrust(obj, k)          
          % Calculate circulation distribution
          obj.prop1.Gamma = gammaCalc(obj.prop1.r./obj.prop1.R,k,obj.a,obj.m);
          
          obj.prop1 = obj.prop1.calculateVelocities();
          obj.prop1 = obj.prop1.calculateForces();
          
          thrust = obj.prop1.Thrust;          
          %disp(obj.prop1.Thrust)
       end
       function k = kAdjust(obj, Treq, kin)
           % Function finds the required k value in the circulation
           % distribution function so the propeller produces sufficient
           % thrust
           rootFunc = @(k)(obj.thrust(k)-Treq);
           
           try               
               [k, fval, exitflag] = fzero(rootFunc,kin,obj.OPTIONS);  
               
           catch
               % set k equal to zero if no solution can be found 
               k = 0;
           end
           
       end
   end
end