% Plot optimal propeller
D = 3.5; % propeller diameter [m]
Z = 4; % number of blades
dHub = 1.020; % hub diameter [m]
rHub = dHub/2; % hub radius [m]
RPM = 150; % revolutions per minute
Vs = 15.5; % ship speed [knots]
h = 4.5; % shaft immersion [m]
NoS = 100; % number of strips 
prop = Propeller(D,Z,rHub,RPM,Vs*0.5144444444,h,NoS);
   
    c_0 = 0.4*D/2;
    c_1 = 1.0;
    a = 0.5;
    m = 0.5;
    prop.c = chordLength(prop.x, c_0, c_1, a, m);

    k = 5.8197;
    a = 0.5;
    m = 0.6;

    prop.Gamma = gammaCalc(prop.r./prop.R,k,a,m);
    prop = prop.calculateVelocities();
    prop = prop.calculateForces();
    prop = prop.calculateGeometricVariables();
    
    figure(1)
    hold on
    % Plot boss
    theta = linspace(0, 2*pi, 100);
        
    xBoss = prop.rBoss*cos(theta);
    yBoss = prop.rBoss*sin(theta);
    
    plot(xBoss, yBoss, 'black')
    
    % Plot blade

    xBlade = prop.r;
    yBlade = prop.c/2;
    yBladeP = prop.c.*cos(prop.phi)/2;
        
    pointsBlade0  = zeros(2, 2*prop.nrStrips);
    pointsBlade0P = zeros(2, 2*prop.nrStrips);
    
    for i = 1:prop.nrStrips
        pointsBlade0(1, i) = xBlade(i);
        pointsBlade0(2, i) = yBlade(i);
            
        pointsBlade0P(1, i) = xBlade(i);
        pointsBlade0P(2, i) = yBladeP(i);
        
        pointsBlade0(1, i+prop.nrStrips) =  xBlade(end-i+1);
        pointsBlade0(2, i+prop.nrStrips) = -yBlade(end-i+1);
            
        pointsBlade0P(1, i+prop.nrStrips) =  xBlade(end-i+1);
        pointsBlade0P(2, i+prop.nrStrips) = -yBladeP(end-i+1);
    end
    % Calculate blade angels
    dThetaBlade = 2*pi/(prop.Z);
        
    if mod(prop.Z,2) == 0
        thetaBlade = pi/2;
    else
        thetaBlade = 0;
    end
        
    for i=1:prop.Z
        R = [cos(thetaBlade),-sin(thetaBlade); sin(thetaBlade), cos(thetaBlade)];
            
        pointsBlade  = R*pointsBlade0;
        pointsBladeP = R*pointsBlade0P;
            
        plot(pointsBlade(1, :), pointsBlade(2, :), '--');
        plot(pointsBladeP(1, :), pointsBladeP(2, :));
            
        thetaBlade = thetaBlade + dThetaBlade;
    end         
    % Plot outer radii
    theta = linspace(0, 2*pi, 100);
        
    xR = prop.R*cos(theta);
    yR = prop.R*sin(theta);
        
    plot(xR, yR);
    
    figure(2)
    hold on
    plot(linspace(-prop.rBoss, prop.rBoss, 2), ones(1,2)*prop.rBoss, 'black')
    plot(linspace(-prop.rBoss, prop.rBoss, 2), -ones(1,2)*prop.rBoss, 'black')
    plot(linspace(-prop.rBoss, prop.rBoss, 2), zeros(1,2), '--')
    
    plot(linspace(-prop.rBoss, prop.rBoss, 2),  ones(1,2)*prop.R, '--')
    plot(linspace(-prop.rBoss, prop.rBoss, 2), -ones(1,2)*prop.R, '--')
    
    y = linspace(prop.rBoss, prop.R, prop.nrStrips);
    x = prop.thickness;
    
    plot( 0.5.*x,  y, 'black');
    plot(-0.5.*x,  y, 'black');
    plot( 0.5.*x, -y, 'black');
    plot(-0.5.*x, -y, 'black');
    
  
    ylim([-prop.R*1.1, prop.R*1.1])
    xlim([-prop.R*1.1, prop.R*1.1])
    
